## Saturday, March 19

### 10:55 - 11:40: Session Block 1A

#### Advocate for Yourself at Work: Use More Free Software and Keep Contributing to the Community

SpeakerTBA

Room 32-141

Your workplace can exert a lot of control over how much free software you use, what you're allowed to work on in your own time and what kinds of tools you become an expert in. New employees don't always negotiate their contracts to make sure they can continue contributing to free software and current employees aren't always successful at advocating for using free software tools, choosing free software technologies or contributing changes back upstream when they do rely on free software. We'll address what's possible, what your legal department is likely to be concerned about and how to be a smooth negotiator at work. Many companies could benefit tremendously from using Free and Open Source Software, but free software enthusiasts and institutional gatekeepers are coming from very different perspectives.

Free software developers and users tend to be most familiar with free software's benefits when compared to proprietary solutions; user freedom, reusing code, public code review for bugs, increased project capacity and cost. The uninitiated may -- unfortunately -- be most familiar with the risks, some real and some perceived. Employers also benefit from having workers who are passionate about their work, are well-connected to the free software community and are constantly learning about new technologies from their peers outside the company, but new employee contracts rarely recognize this unless you ask. Conversations about contracts, choosing new technologies and sharing an employee's work with another entity are high stakes negotiations. With a solid understanding of what worries and motivates the other parties, you can become a savvy advocate for free software at work.

This talk will help you gather information, frame the conversation and make the best possible case for using and contributing to free software at work.

#### Building new economies for open development and content

Paige Peterson, MaidSoft

RoomTBA

DescTBA

#### Challenges and future growth in libre media and conference video production

George Chriss and others, Kat Walsh (moderator)

Room 32-144

DescTBA

### 11:50 - 12:30: Session Block 2A

#### A community take on the license compliance industry

SpeakerTBA

Room 31-123

DescTBA

#### Community technology for solidarity economies

Andrew Seeder, Dudley Street Neighborhood Initiative

RoomTBA

DescTBA

#### Effective outreach in four steps

Marina Zhurakhinskaya, Red Hat

Room 32-144

DescTBA

### 13:00 - 13:50: Session Block 3A

#### Free software alternatives to dominant proprietary solutions: A review of French initiatives

Marianne Corvellec, April and Jonathan Le Lous, April

RoomTBA

DescTBA

#### FSF at 30: history of free software

SpeakerTBA

RoomTBA

A look back at free software history, with a live demonstration of software from the past being used to deliver a presentation in 2016.

#### Getting the academy to support free software and open science

Scott Dexter and Evan Misshula, CUNY, and Erin Glass, UCSD

RoomTBA

Academic Institutions and their researchers are some of the biggest beneficiaries of free software development. While individual researchers have contributed greatly to free software, they usually do so outside of the scope of their regular jobs and to the detriment of their academic careers.

At CUNY, we have taken steps to change this unacceptable situation. Please come to this session and exchange ideas and strategies for having contribtions to free software valued by the University.

#### GNU/Linux and Chill: Free Software on a College Campus

Michaela R. Brown

Room 42-042

Being a free software user isn't easy, especially when you're a college student. I spent a year at a school that taught Visual Basic as its primary programming language for freshmen and sophomores, where "Introduction to Programming" was an overview of the Windows OS, and where most of the professors would only accept papers typed in Times New Roman -- and I survived.

In this session, I'll give students tips for making it through college while still adhering to the values we hold as free software users -- including alternative fonts, making a GNU/Linux live disk for use on public computers, avoiding the "Netflix and Chill" dilemma, and most importantly, ways to discuss free software with professors and fellow students. After leaving this session, students will feel empowered and able to hold their own as free users in a proprietary campus.
